# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v2/lease.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csentinel/node/v2/lease.proto\x12\x10sentinel.node.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\"\x89\x01\n\x05Lease\x12\x12\n\x02id\x18\x01 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x14\n\x0cnode_address\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\t\x12\r\n\x05hours\x18\x04 \x01(\x03\x12.\n\x05price\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x42\x37Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.lease_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _LEASE.fields_by_name['id']._options = None
  _LEASE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _LEASE.fields_by_name['price']._options = None
  _LEASE.fields_by_name['price']._serialized_options = b'\310\336\037\000'
  _LEASE._serialized_start=105
  _LEASE._serialized_end=242
# @@protoc_insertion_point(module_scope)
