# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v2/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sentinel/subscription/v2/msg.proto\x12\x18sentinel.subscription.v2\x1a\x14gogoproto/gogo.proto\",\n\x10MsgCancelRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\"{\n\x0fMsgShareRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x81\x01\n\x15MsgUpdateQuotaRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x13\n\x11MsgCancelResponse\"\x12\n\x10MsgShareResponse\"\x18\n\x16MsgUpdateQuotaResponse2\xca\x02\n\nMsgService\x12\x64\n\tMsgCancel\x12*.sentinel.subscription.v2.MsgCancelRequest\x1a+.sentinel.subscription.v2.MsgCancelResponse\x12\x61\n\x08MsgShare\x12).sentinel.subscription.v2.MsgShareRequest\x1a*.sentinel.subscription.v2.MsgShareResponse\x12s\n\x0eMsgUpdateQuota\x12/.sentinel.subscription.v2.MsgUpdateQuotaRequest\x1a\x30.sentinel.subscription.v2.MsgUpdateQuotaResponseB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _MSGSHAREREQUEST.fields_by_name['bytes']._options = None
  _MSGSHAREREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._options = None
  _MSGUPDATEQUOTAREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGCANCELREQUEST._serialized_start=86
  _MSGCANCELREQUEST._serialized_end=130
  _MSGSHAREREQUEST._serialized_start=132
  _MSGSHAREREQUEST._serialized_end=255
  _MSGUPDATEQUOTAREQUEST._serialized_start=258
  _MSGUPDATEQUOTAREQUEST._serialized_end=387
  _MSGCANCELRESPONSE._serialized_start=389
  _MSGCANCELRESPONSE._serialized_end=408
  _MSGSHARERESPONSE._serialized_start=410
  _MSGSHARERESPONSE._serialized_end=428
  _MSGUPDATEQUOTARESPONSE._serialized_start=430
  _MSGUPDATEQUOTARESPONSE._serialized_end=454
  _MSGSERVICE._serialized_start=457
  _MSGSERVICE._serialized_end=787
# @@protoc_insertion_point(module_scope)
