# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/subscription/v2/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+sentinel/subscription/v2/subscription.proto\x12\x18sentinel.subscription.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto\"\xa3\x01\n\x10\x42\x61seSubscription\x12\x12\n\x02id\x18\x01 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12\x37\n\tstatus_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xab\x01\n\x10NodeSubscription\x12\x42\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32*.sentinel.subscription.v2.BaseSubscriptionB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x12\x14\n\x0cnode_address\x18\x02 \x01(\t\x12\r\n\x05hours\x18\x03 \x01(\x03\x12.\n\x05price\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x82\x01\n\x10PlanSubscription\x12\x42\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32*.sentinel.subscription.v2.BaseSubscriptionB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x12\x1b\n\x07plan_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06PlanID\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t*}\n\x10SubscriptionType\x12)\n\x10TYPE_UNSPECIFIED\x10\x00\x1a\x13\x8a\x9d \x0fTypeUnspecified\x12\x1b\n\tTYPE_NODE\x10\x01\x1a\x0c\x8a\x9d \x08TypeNode\x12\x1b\n\tTYPE_PLAN\x10\x02\x1a\x0c\x8a\x9d \x08TypePlan\x1a\x04\x88\xa3\x1e\x00\x42?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\250\342\036\000\310\341\036\000'
  _SUBSCRIPTIONTYPE._options = None
  _SUBSCRIPTIONTYPE._serialized_options = b'\210\243\036\000'
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_UNSPECIFIED"]._options = None
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \017TypeUnspecified'
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_NODE"]._options = None
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_NODE"]._serialized_options = b'\212\235 \010TypeNode'
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_PLAN"]._options = None
  _SUBSCRIPTIONTYPE.values_by_name["TYPE_PLAN"]._serialized_options = b'\212\235 \010TypePlan'
  _BASESUBSCRIPTION.fields_by_name['id']._options = None
  _BASESUBSCRIPTION.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _BASESUBSCRIPTION.fields_by_name['status_at']._options = None
  _BASESUBSCRIPTION.fields_by_name['status_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _NODESUBSCRIPTION.fields_by_name['base']._options = None
  _NODESUBSCRIPTION.fields_by_name['base']._serialized_options = b'\320\336\037\001\310\336\037\000'
  _NODESUBSCRIPTION.fields_by_name['price']._options = None
  _NODESUBSCRIPTION.fields_by_name['price']._serialized_options = b'\310\336\037\000'
  _PLANSUBSCRIPTION.fields_by_name['base']._options = None
  _PLANSUBSCRIPTION.fields_by_name['base']._serialized_options = b'\320\336\037\001\310\336\037\000'
  _PLANSUBSCRIPTION.fields_by_name['plan_id']._options = None
  _PLANSUBSCRIPTION.fields_by_name['plan_id']._serialized_options = b'\342\336\037\006PlanID'
  _SUBSCRIPTIONTYPE._serialized_start=665
  _SUBSCRIPTIONTYPE._serialized_end=790
  _BASESUBSCRIPTION._serialized_start=193
  _BASESUBSCRIPTION._serialized_end=356
  _NODESUBSCRIPTION._serialized_start=359
  _NODESUBSCRIPTION._serialized_end=530
  _PLANSUBSCRIPTION._serialized_start=533
  _PLANSUBSCRIPTION._serialized_end=663
# @@protoc_insertion_point(module_scope)
