# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/session/v2/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sentinel/session/v2/events.proto\x12\x13sentinel.session.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto\"u\n\nEventStart\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\"v\n\x0b\x45ventUpdate\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\"\xb7\x01\n\x0e\x45ventSetStatus\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\x12<\n\x06status\x18\x04 \x01(\x0e\x32\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:\"status\"\"\xb5\x01\n\x08\x45ventPay\x12\x19\n\x02id\x18\x01 \x01(\x04\x42\r\xf2\xde\x1f\tyaml:\"id\"\x12\x1d\n\x04node\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"node\"\x12-\n\x0csubscription\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"subscription\"\x12@\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xf2\xde\x1f\ryaml:\"amount\"\xc8\xde\x1f\x00\x42:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v2.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\250\342\036\000\310\341\036\000'
  _EVENTSTART.fields_by_name['id']._options = None
  _EVENTSTART.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSTART.fields_by_name['node']._options = None
  _EVENTSTART.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTSTART.fields_by_name['subscription']._options = None
  _EVENTSTART.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTUPDATE.fields_by_name['id']._options = None
  _EVENTUPDATE.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTUPDATE.fields_by_name['node']._options = None
  _EVENTUPDATE.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTUPDATE.fields_by_name['subscription']._options = None
  _EVENTUPDATE.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTSETSTATUS.fields_by_name['id']._options = None
  _EVENTSETSTATUS.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTSETSTATUS.fields_by_name['node']._options = None
  _EVENTSETSTATUS.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTSETSTATUS.fields_by_name['subscription']._options = None
  _EVENTSETSTATUS.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTSETSTATUS.fields_by_name['status']._options = None
  _EVENTSETSTATUS.fields_by_name['status']._serialized_options = b'\362\336\037\ryaml:\"status\"'
  _EVENTPAY.fields_by_name['id']._options = None
  _EVENTPAY.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _EVENTPAY.fields_by_name['node']._options = None
  _EVENTPAY.fields_by_name['node']._serialized_options = b'\362\336\037\013yaml:\"node\"'
  _EVENTPAY.fields_by_name['subscription']._options = None
  _EVENTPAY.fields_by_name['subscription']._serialized_options = b'\362\336\037\023yaml:\"subscription\"'
  _EVENTPAY.fields_by_name['amount']._options = None
  _EVENTPAY.fields_by_name['amount']._serialized_options = b'\362\336\037\ryaml:\"amount\"\310\336\037\000'
  _EVENTSTART._serialized_start=143
  _EVENTSTART._serialized_end=260
  _EVENTUPDATE._serialized_start=262
  _EVENTUPDATE._serialized_end=380
  _EVENTSETSTATUS._serialized_start=383
  _EVENTSETSTATUS._serialized_end=566
  _EVENTPAY._serialized_start=569
  _EVENTPAY._serialized_end=750
# @@protoc_insertion_point(module_scope)
