# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/node/v2/querier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from sentinel.node.v2 import lease_pb2 as sentinel_dot_node_dot_v2_dot_lease__pb2
from sentinel.node.v2 import node_pb2 as sentinel_dot_node_dot_v2_dot_node__pb2
from sentinel.node.v2 import params_pb2 as sentinel_dot_node_dot_v2_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/node/v2/querier.proto\x12\x10sentinel.node.v2\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a\x1csentinel/node/v2/lease.proto\x1a\x1bsentinel/node/v2/node.proto\x1a\x1dsentinel/node/v2/params.proto\"z\n\x11QueryNodesRequest\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x18QueryNodesForPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"#\n\x10QueryNodeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"P\n\x12QueryLeasesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"k\n\x1cQueryLeasesForAccountRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"h\n\x19QueryLeasesForNodeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x1f\n\x11QueryLeaseRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"\x14\n\x12QueryParamsRequest\"~\n\x12QueryNodesResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x85\x01\n\x19QueryNodesForPlanResponse\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"?\n\x11QueryNodeResponse\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x16.sentinel.node.v2.NodeB\x04\xc8\xde\x1f\x00\"\x81\x01\n\x13QueryLeasesResponse\x12-\n\x06leases\x18\x01 \x03(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x8b\x01\n\x1dQueryLeasesForAccountResponse\x12-\n\x06leases\x18\x01 \x03(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x88\x01\n\x1aQueryLeasesForNodeResponse\x12-\n\x06leases\x18\x01 \x03(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"B\n\x12QueryLeaseResponse\x12,\n\x05lease\x18\x01 \x01(\x0b\x32\x17.sentinel.node.v2.LeaseB\x04\xc8\xde\x1f\x00\"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.sentinel.node.v2.ParamsB\x04\xc8\xde\x1f\x00\x32\xc2\x08\n\x0cQueryService\x12p\n\nQueryNodes\x12#.sentinel.node.v2.QueryNodesRequest\x1a$.sentinel.node.v2.QueryNodesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/nodes\x12\x90\x01\n\x11QueryNodesForPlan\x12*.sentinel.node.v2.QueryNodesForPlanRequest\x1a+.sentinel.node.v2.QueryNodesForPlanResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/sentinel/plans/{id}/nodes\x12w\n\tQueryNode\x12\".sentinel.node.v2.QueryNodeRequest\x1a#.sentinel.node.v2.QueryNodeResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/nodes/{address}\x12t\n\x0bQueryLeases\x12$.sentinel.node.v2.QueryLeasesRequest\x1a%.sentinel.node.v2.QueryLeasesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/sentinel/leases\x12\xa5\x01\n\x15QueryLeasesForAccount\x12..sentinel.node.v2.QueryLeasesForAccountRequest\x1a/.sentinel.node.v2.QueryLeasesForAccountResponse\"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/accounts/{address}/leases\x12\x99\x01\n\x12QueryLeasesForNode\x12+.sentinel.node.v2.QueryLeasesForNodeRequest\x1a,.sentinel.node.v2.QueryLeasesForNodeResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /sentinel/nodes/{address}/leases\x12v\n\nQueryLease\x12#.sentinel.node.v2.QueryLeaseRequest\x1a$.sentinel.node.v2.QueryLeaseResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/sentinel/leases/{id}\x12\x81\x01\n\x0bQueryParams\x12$.sentinel.node.v2.QueryParamsRequest\x1a%.sentinel.node.v2.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/modules/node/paramsB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.querier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\250\342\036\000\310\341\036\000'
  _QUERYNODESRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._options = None
  _QUERYNODESFORPLANRESPONSE.fields_by_name['nodes']._serialized_options = b'\310\336\037\000'
  _QUERYNODERESPONSE.fields_by_name['node']._options = None
  _QUERYNODERESPONSE.fields_by_name['node']._serialized_options = b'\310\336\037\000'
  _QUERYLEASESRESPONSE.fields_by_name['leases']._options = None
  _QUERYLEASESRESPONSE.fields_by_name['leases']._serialized_options = b'\310\336\037\000'
  _QUERYLEASESFORACCOUNTRESPONSE.fields_by_name['leases']._options = None
  _QUERYLEASESFORACCOUNTRESPONSE.fields_by_name['leases']._serialized_options = b'\310\336\037\000'
  _QUERYLEASESFORNODERESPONSE.fields_by_name['leases']._options = None
  _QUERYLEASESFORNODERESPONSE.fields_by_name['leases']._serialized_options = b'\310\336\037\000'
  _QUERYLEASERESPONSE.fields_by_name['lease']._options = None
  _QUERYLEASERESPONSE.fields_by_name['lease']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSERVICE.methods_by_name['QueryNodes']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodes']._serialized_options = b'\202\323\344\223\002\021\022\017/sentinel/nodes'
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._options = None
  _QUERYSERVICE.methods_by_name['QueryNodesForPlan']._serialized_options = b'\202\323\344\223\002\034\022\032/sentinel/plans/{id}/nodes'
  _QUERYSERVICE.methods_by_name['QueryNode']._options = None
  _QUERYSERVICE.methods_by_name['QueryNode']._serialized_options = b'\202\323\344\223\002\033\022\031/sentinel/nodes/{address}'
  _QUERYSERVICE.methods_by_name['QueryLeases']._options = None
  _QUERYSERVICE.methods_by_name['QueryLeases']._serialized_options = b'\202\323\344\223\002\022\022\020/sentinel/leases'
  _QUERYSERVICE.methods_by_name['QueryLeasesForAccount']._options = None
  _QUERYSERVICE.methods_by_name['QueryLeasesForAccount']._serialized_options = b'\202\323\344\223\002%\022#/sentinel/accounts/{address}/leases'
  _QUERYSERVICE.methods_by_name['QueryLeasesForNode']._options = None
  _QUERYSERVICE.methods_by_name['QueryLeasesForNode']._serialized_options = b'\202\323\344\223\002\"\022 /sentinel/nodes/{address}/leases'
  _QUERYSERVICE.methods_by_name['QueryLease']._options = None
  _QUERYSERVICE.methods_by_name['QueryLease']._serialized_options = b'\202\323\344\223\002\027\022\025/sentinel/leases/{id}'
  _QUERYSERVICE.methods_by_name['QueryParams']._options = None
  _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\037\022\035/sentinel/modules/node/params'
  _QUERYNODESREQUEST._serialized_start=270
  _QUERYNODESREQUEST._serialized_end=392
  _QUERYNODESFORPLANREQUEST._serialized_start=395
  _QUERYNODESFORPLANREQUEST._serialized_end=536
  _QUERYNODEREQUEST._serialized_start=538
  _QUERYNODEREQUEST._serialized_end=573
  _QUERYLEASESREQUEST._serialized_start=575
  _QUERYLEASESREQUEST._serialized_end=655
  _QUERYLEASESFORACCOUNTREQUEST._serialized_start=657
  _QUERYLEASESFORACCOUNTREQUEST._serialized_end=764
  _QUERYLEASESFORNODEREQUEST._serialized_start=766
  _QUERYLEASESFORNODEREQUEST._serialized_end=870
  _QUERYLEASEREQUEST._serialized_start=872
  _QUERYLEASEREQUEST._serialized_end=903
  _QUERYPARAMSREQUEST._serialized_start=905
  _QUERYPARAMSREQUEST._serialized_end=925
  _QUERYNODESRESPONSE._serialized_start=927
  _QUERYNODESRESPONSE._serialized_end=1053
  _QUERYNODESFORPLANRESPONSE._serialized_start=1056
  _QUERYNODESFORPLANRESPONSE._serialized_end=1189
  _QUERYNODERESPONSE._serialized_start=1191
  _QUERYNODERESPONSE._serialized_end=1254
  _QUERYLEASESRESPONSE._serialized_start=1257
  _QUERYLEASESRESPONSE._serialized_end=1386
  _QUERYLEASESFORACCOUNTRESPONSE._serialized_start=1389
  _QUERYLEASESFORACCOUNTRESPONSE._serialized_end=1528
  _QUERYLEASESFORNODERESPONSE._serialized_start=1531
  _QUERYLEASESFORNODERESPONSE._serialized_end=1667
  _QUERYLEASERESPONSE._serialized_start=1669
  _QUERYLEASERESPONSE._serialized_end=1735
  _QUERYPARAMSRESPONSE._serialized_start=1737
  _QUERYPARAMSRESPONSE._serialized_end=1806
  _QUERYSERVICE._serialized_start=1809
  _QUERYSERVICE._serialized_end=2899
# @@protoc_insertion_point(module_scope)
