# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/plan/v2/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/plan/v2/events.proto\x12\x10sentinel.plan.v2\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto\"e\n\x0b\x45ventCreate\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12\x35\n\x10provider_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"\"\xa9\x01\n\x11\x45ventUpdateStatus\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12\x35\n\x10provider_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"\x12<\n\x06status\x18\x03 \x01(\x0e\x32\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:\"status\"\"\x96\x01\n\rEventLinkNode\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"node_address\"\x12\x35\n\x10provider_address\x18\x03 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"\"\x98\x01\n\x0f\x45ventUnlinkNode\x12\x1f\n\x02id\x18\x01 \x01(\x04\x42\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:\"id\"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"node_address\"\x12\x35\n\x10provider_address\x18\x03 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"provider_address\"B7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\250\342\036\000\310\341\036\000'
  _EVENTCREATE.fields_by_name['id']._options = None
  _EVENTCREATE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTCREATE.fields_by_name['provider_address']._options = None
  _EVENTCREATE.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTUPDATESTATUS.fields_by_name['id']._options = None
  _EVENTUPDATESTATUS.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTUPDATESTATUS.fields_by_name['provider_address']._options = None
  _EVENTUPDATESTATUS.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTUPDATESTATUS.fields_by_name['status']._options = None
  _EVENTUPDATESTATUS.fields_by_name['status']._serialized_options = b'\362\336\037\ryaml:\"status\"'
  _EVENTLINKNODE.fields_by_name['id']._options = None
  _EVENTLINKNODE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTLINKNODE.fields_by_name['node_address']._options = None
  _EVENTLINKNODE.fields_by_name['node_address']._serialized_options = b'\362\336\037\023yaml:\"node_address\"'
  _EVENTLINKNODE.fields_by_name['provider_address']._options = None
  _EVENTLINKNODE.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTUNLINKNODE.fields_by_name['id']._options = None
  _EVENTUNLINKNODE.fields_by_name['id']._serialized_options = b'\342\336\037\002ID\362\336\037\tyaml:\"id\"'
  _EVENTUNLINKNODE.fields_by_name['node_address']._options = None
  _EVENTUNLINKNODE.fields_by_name['node_address']._serialized_options = b'\362\336\037\023yaml:\"node_address\"'
  _EVENTUNLINKNODE.fields_by_name['provider_address']._options = None
  _EVENTUNLINKNODE.fields_by_name['provider_address']._serialized_options = b'\362\336\037\027yaml:\"provider_address\"'
  _EVENTCREATE._serialized_start=105
  _EVENTCREATE._serialized_end=206
  _EVENTUPDATESTATUS._serialized_start=209
  _EVENTUPDATESTATUS._serialized_end=378
  _EVENTLINKNODE._serialized_start=381
  _EVENTLINKNODE._serialized_end=531
  _EVENTUNLINKNODE._serialized_start=534
  _EVENTUNLINKNODE._serialized_end=686
# @@protoc_insertion_point(module_scope)
