syntax = "proto3";
package sentinel.swap.v1;

option go_package = "github.com/sentinel-official/hub/x/swap/types";

import "gogoproto/gogo.proto";
import "sentinel/swap/v1/params.proto";
import "sentinel/swap/v1/swap.proto";

option (gogoproto.equal_all)           = false;
option (gogoproto.goproto_getters_all) = false;

message GenesisState {
  repeated Swap swaps = 1
      [ (gogoproto.jsontag) = "_,omitempty", (gogoproto.nullable) = false ];
  Params params = 2 [ (gogoproto.nullable) = false ];
}
