# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentinel/plan/v2/msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/plan/v2/msg.proto\x12\x10sentinel.plan.v2\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1esentinel/types/v1/status.proto\"\xf3\x01\n\x10MsgCreateRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12[\n\x06prices\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x35\n\x08validity\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12=\n\x05\x62ytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"e\n\x16MsgUpdateStatusRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.sentinel.types.v1.Status\"G\n\x12MsgLinkNodeRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"I\n\x14MsgUnlinkNodeRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"F\n\x13MsgSubscribeRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04\x42\x06\xe2\xde\x1f\x02ID\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"\x13\n\x11MsgCreateResponse\"\x19\n\x17MsgUpdateStatusResponse\"\x15\n\x13MsgLinkNodeResponse\"\x17\n\x15MsgUnlinkNodeResponse\"\x16\n\x14MsgSubscribeResponse2\xe7\x03\n\nMsgService\x12T\n\tMsgCreate\x12\".sentinel.plan.v2.MsgCreateRequest\x1a#.sentinel.plan.v2.MsgCreateResponse\x12\x66\n\x0fMsgUpdateStatus\x12(.sentinel.plan.v2.MsgUpdateStatusRequest\x1a).sentinel.plan.v2.MsgUpdateStatusResponse\x12Z\n\x0bMsgLinkNode\x12$.sentinel.plan.v2.MsgLinkNodeRequest\x1a%.sentinel.plan.v2.MsgLinkNodeResponse\x12`\n\rMsgUnlinkNode\x12&.sentinel.plan.v2.MsgUnlinkNodeRequest\x1a\'.sentinel.plan.v2.MsgUnlinkNodeResponse\x12]\n\x0cMsgSubscribe\x12%.sentinel.plan.v2.MsgSubscribeRequest\x1a&.sentinel.plan.v2.MsgSubscribeResponseB7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.msg_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\250\342\036\000\310\341\036\000'
  _MSGCREATEREQUEST.fields_by_name['prices']._options = None
  _MSGCREATEREQUEST.fields_by_name['prices']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATEREQUEST.fields_by_name['validity']._options = None
  _MSGCREATEREQUEST.fields_by_name['validity']._serialized_options = b'\230\337\037\001\310\336\037\000'
  _MSGCREATEREQUEST.fields_by_name['bytes']._options = None
  _MSGCREATEREQUEST.fields_by_name['bytes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGUPDATESTATUSREQUEST.fields_by_name['id']._options = None
  _MSGUPDATESTATUSREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGLINKNODEREQUEST.fields_by_name['id']._options = None
  _MSGLINKNODEREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGUNLINKNODEREQUEST.fields_by_name['id']._options = None
  _MSGUNLINKNODEREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGSUBSCRIBEREQUEST.fields_by_name['id']._options = None
  _MSGSUBSCRIBEREQUEST.fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _MSGCREATEREQUEST._serialized_start=167
  _MSGCREATEREQUEST._serialized_end=410
  _MSGUPDATESTATUSREQUEST._serialized_start=412
  _MSGUPDATESTATUSREQUEST._serialized_end=513
  _MSGLINKNODEREQUEST._serialized_start=515
  _MSGLINKNODEREQUEST._serialized_end=586
  _MSGUNLINKNODEREQUEST._serialized_start=588
  _MSGUNLINKNODEREQUEST._serialized_end=661
  _MSGSUBSCRIBEREQUEST._serialized_start=663
  _MSGSUBSCRIBEREQUEST._serialized_end=733
  _MSGCREATERESPONSE._serialized_start=735
  _MSGCREATERESPONSE._serialized_end=754
  _MSGUPDATESTATUSRESPONSE._serialized_start=756
  _MSGUPDATESTATUSRESPONSE._serialized_end=781
  _MSGLINKNODERESPONSE._serialized_start=783
  _MSGLINKNODERESPONSE._serialized_end=804
  _MSGUNLINKNODERESPONSE._serialized_start=806
  _MSGUNLINKNODERESPONSE._serialized_end=829
  _MSGSUBSCRIBERESPONSE._serialized_start=831
  _MSGSUBSCRIBERESPONSE._serialized_end=853
  _MSGSERVICE._serialized_start=856
  _MSGSERVICE._serialized_end=1343
# @@protoc_insertion_point(module_scope)
